@@ -9,7 +9,8 @@
 #  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #  License for the specific language governing permissions and limitations
 #  under the License.
-import collections
+
+import collections.abc
 
 from oslo_policy import policy
 import pecan
@@ -17,9 +18,12 @@ from webob import exc
 
 from barbican import api
 from barbican.common import accept
+from barbican.common import config
 from barbican.common import utils
 from barbican import i18n as u
 
+
+CONF = config.CONF
 LOG = utils.getLogger(__name__)
 
 
@@ -49,27 +53,22 @@ def _do_enforce_rbac(inst, req, action_name, ctx, **kwargs):
     """Enforce RBAC based on 'request' information."""
     if action_name and ctx:
 
-        # Prepare credentials information.
-        credentials = {
-            'roles': ctx.roles,
-            'user': ctx.user,
-            'project': ctx.project_id
-        }
-
         # Enforce special case: secret GET decryption
         if 'secret:get' == action_name and not is_json_request_accept(req):
             action_name = 'secret:decrypt'  # Override to perform special rules
 
         target_name, target_data = inst.get_acl_tuple(req, **kwargs)
-        policy_dict = {}
+        policy_dict = {
+            "enforce_new_defaults": CONF.oslo_policy.enforce_new_defaults
+        }
         if target_name and target_data:
             policy_dict['target'] = {target_name: target_data}
 
-        policy_dict.update(kwargs)
         # Enforce access controls.
         if ctx.policy_enforcer:
-            ctx.policy_enforcer.enforce(action_name, flatten(policy_dict),
-                                        credentials, do_raise=True)
+            target = flatten(policy_dict)
+            ctx.policy_enforcer.authorize(action_name, target,
+                                          ctx, do_raise=True)
 
 
 def enforce_rbac(action_name='default'):
@@ -170,7 +169,7 @@ def flatten(d, parent_key=''):
     items = []
     for k, v in d.items():
         new_key = parent_key + '.' + k if parent_key else k
-        if isinstance(v, collections.MutableMapping):
+        if isinstance(v, collections.abc.MutableMapping):
             items.extend(flatten(v, new_key).items())
         else:
             items.append((new_key, v))
@@ -179,8 +178,22 @@ def flatten(d, parent_key=''):
 
 class ACLMixin(object):
 
+    def __init__(self):
+        self.secret = None
+        self.container = None
+
     def get_acl_tuple(self, req, **kwargs):
-        return None, None
+        if self.secret is not None:
+            entity = 'secret'
+        elif self.container is not None:
+            entity = 'container'
+        else:
+            return None, None
+        entity_acls = getattr(getattr(self, entity), '{}_acls'.format(entity))
+        acl = self.get_acl_dict_for_user(req, entity_acls)
+        acl['project_id'] = getattr(self, entity).project.external_id
+        acl['creator_id'] = getattr(self, entity).creator_id
+        return entity, acl
 
     def get_acl_dict_for_user(self, req, acl_list):
         """Get acl operation found for token user in acl list.
@@ -220,9 +233,26 @@ class ACLMixin(object):
         if not ctxt:
             return {}
         acl_dict = {acl.operation: acl.operation for acl in acl_list
-                    if ctxt.user in acl.to_dict_fields().get('users', [])}
+                    if ctxt.user_id in acl.to_dict_fields().get('users', [])}
         co_dict = {'%s_project_access' % acl.operation: acl.project_access for
                    acl in acl_list if acl.project_access is not None}
+        if not co_dict:
+            """
+            The co_dict is empty when the entity (secret or container) has no
+            acls in its acl_list.  This causes any policy with
+
+                "%(target.secret.read_project_access)s"
+            or
+                "%(target.container.read_project_access)s"
+
+            to always evaluate to False.  This is probelmatic because we want
+            to allow project access by default (with additional role checks).
+            To work around this we allow read here.
+
+            When the entity has an acl, co_dict will use the value from the
+            database, and this if statement will be skipped.
+            """
+            co_dict = {'read_project_access': True}
         acl_dict.update(co_dict)
 
         return acl_dict
