@@ -45,21 +45,16 @@ class ContainerController(controllers.ACLMixin):
     """Handles Container entity retrieval and deletion requests."""
 
     def __init__(self, container):
+        super().__init__()
         self.container = container
         self.container_id = container.id
         self.consumer_repo = repo.get_container_consumer_repository()
         self.container_repo = repo.get_container_repository()
         self.validator = validators.ContainerValidator()
         self.consumers = consumers.ContainerConsumersController(
-            self.container_id)
+            self.container)
         self.acl = acls.ContainerACLsController(self.container)
 
-    def get_acl_tuple(self, req, **kwargs):
-        d = self.get_acl_dict_for_user(req, self.container.container_acls)
-        d['project_id'] = self.container.project.external_id
-        d['creator_id'] = self.container.creator_id
-        return 'container', d
-
     @pecan.expose(generic=True, template='json')
     def index(self, **kwargs):
         pecan.abort(405)  # HTTP 405 Method Not Allowed as default
@@ -112,6 +107,7 @@ class ContainersController(controllers.ACLMixin):
     """Handles Container creation requests."""
 
     def __init__(self):
+        super().__init__()
         self.consumer_repo = repo.get_container_consumer_repository()
         self.container_repo = repo.get_container_repository()
         self.secret_repo = repo.get_secret_repository()
@@ -189,7 +185,7 @@ class ContainersController(controllers.ACLMixin):
         data = api.load_body(pecan.request, validator=self.validator)
         ctxt = controllers._get_barbican_context(pecan.request)
         if ctxt:  # in authenticated pipleline case, always use auth token user
-            data['creator_id'] = ctxt.user
+            data['creator_id'] = ctxt.user_id
 
         self.quota_enforcer.enforce(project)
 
@@ -230,6 +226,7 @@ class ContainersSecretsController(controllers.ACLMixin):
 
     def __init__(self, container):
         LOG.debug('=== Creating ContainerSecretsController ===')
+        super().__init__()
         self.container = container
         self.container_secret_repo = repo.get_container_secret_repository()
         self.secret_repo = repo.get_secret_repository()
