@@ -21,10 +21,11 @@ import logging
 import os
 
 from oslo_config import cfg
+from oslo_db import options as db_options
 from oslo_log import log
 from oslo_middleware import cors
-from oslo_policy import opts as policy_opts
-from oslo_service import _options
+from oslo_service.backend import BackendType
+from oslo_service.backend import register_backend_default_hook
 
 from barbican import i18n as u
 import barbican.version
@@ -65,31 +66,6 @@ host_opts = [
 ]
 
 db_opts = [
-    cfg.StrOpt('sql_connection',
-               default="sqlite:///barbican.sqlite",
-               secret=True,
-               help=u._("SQLAlchemy connection string for the reference "
-                        "implementation registry server. Any valid "
-                        "SQLAlchemy connection string is fine. See: "
-                        "http://www.sqlalchemy.org/docs/05/reference/"
-                        "sqlalchemy/connections.html#sqlalchemy."
-                        "create_engine. Note: For absolute addresses, use "
-                        "'////' slashes after 'sqlite:'.")),
-    cfg.IntOpt('sql_idle_timeout', default=3600,
-               help=u._("Period in seconds after which SQLAlchemy should "
-                        "reestablish its connection to the database. MySQL "
-                        "uses a default `wait_timeout` of 8 hours, after "
-                        "which it will drop idle connections. This can result "
-                        "in 'MySQL Gone Away' exceptions. If you notice this, "
-                        "you can lower this value to ensure that SQLAlchemy "
-                        "reconnects before MySQL can drop the connection.")),
-    cfg.IntOpt('sql_max_retries', default=60,
-               help=u._("Maximum number of database connection retries "
-                        "during startup. Set to -1 to specify an infinite "
-                        "retry count.")),
-    cfg.IntOpt('sql_retry_interval', default=1,
-               help=u._("Interval between retries of opening a SQL "
-                        "connection.")),
     cfg.BoolOpt('db_auto_create', default=False,
                 help=u._("Create the Barbican database on service startup.")),
     cfg.IntOpt('max_limit_paging', default=100,
@@ -110,25 +86,6 @@ db_opts = [
     cfg.BoolOpt('sql_pool_logging', default=False,
                 help=u._("Show SQLAlchemy pool-related debugging output in "
                          "logs (sets DEBUG log level output) if specified.")),
-    cfg.IntOpt('sql_pool_size', default=5,
-               help=u._("Size of pool used by SQLAlchemy. This is the largest "
-                        "number of connections that will be kept persistently "
-                        "in the pool. Can be set to 0 to indicate no size "
-                        "limit. To disable pooling, use a NullPool with "
-                        "sql_pool_class instead. Comment out to allow "
-                        "SQLAlchemy to select the default.")),
-    cfg.IntOpt('sql_pool_max_overflow', default=10,
-               help=u._("# The maximum overflow size of the pool used by "
-                        "SQLAlchemy. When the number of checked-out "
-                        "connections reaches the size set in sql_pool_size, "
-                        "additional connections will be returned up to this "
-                        "limit. It follows then that the total number of "
-                        "simultaneous connections the pool will allow is "
-                        "sql_pool_size + sql_pool_max_overflow. Can be set "
-                        "to -1 to indicate no overflow limit, so no limit "
-                        "will be placed on the total number of concurrent "
-                        "connections. Comment out to allow SQLAlchemy to "
-                        "select the default.")),
 ]
 
 retry_opt_group = cfg.OptGroup(name='retry_scheduler',
@@ -238,7 +195,6 @@ def list_opts():
     yield None, common_opts
     yield None, host_opts
     yield None, db_opts
-    yield None, _options.eventlet_backdoor_opts
     yield retry_opt_group, retry_opts
     yield queue_opt_group, queue_opts
     yield ks_queue_opt_group, ks_queue_opts
@@ -271,14 +227,12 @@ def parse_args(conf, args=None, usage=None, default_config_files=None):
 def new_config():
     conf = cfg.ConfigOpts()
     log.register_options(conf)
+    db_options.set_defaults(conf, connection='sqlite:///barbican.sqlite')
+
     conf.register_opts(context_opts)
     conf.register_opts(common_opts)
     conf.register_opts(host_opts)
     conf.register_opts(db_opts)
-    conf.register_opts(_options.eventlet_backdoor_opts)
-    conf.register_opts(_options.periodic_opts)
-
-    conf.register_opts(_options.ssl_opts, "ssl")
 
     conf.register_group(retry_opt_group)
     conf.register_opts(retry_opts, group=retry_opt_group)
@@ -334,12 +288,6 @@ def set_lib_defaults():
 
     set_middleware_defaults()
 
-    # TODO(gmann): Remove setting the default value of config policy_file
-    # once oslo_policy change the default value to 'policy.yaml'.
-    # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
-    DEFAULT_POLICY_FILE = 'policy.yaml'
-    policy_opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
-
 
 def set_middleware_defaults():
     """Update default configuration options for oslo.middleware."""
@@ -376,6 +324,10 @@ CONF = new_config()
 LOG = logging.getLogger(__name__)
 parse_args(CONF)
 
+# Register default backend hook to prefer threading if not initialized
+# elsewhere
+register_backend_default_hook(lambda: BackendType.THREADING)
+
 # Adding global scope dict for all different configs created in various
 # modules. In barbican, each plugin module creates its own *new* config
 # instance so its error prone to share/access config values across modules
