@@ -26,10 +26,14 @@ LOG = utils.getLogger(__name__)
 Attribute = collections.namedtuple("Attribute", ["type", "value"])
 CKAttributes = collections.namedtuple("CKAttributes", ["template", "cffivals"])
 CKMechanism = collections.namedtuple("CKMechanism", ["mech", "cffivals"])
+Token = collections.namedtuple("Token", ["slot_id", "label", "serial_number"])
 
 CKR_OK = 0
+CKR_CRYPTOKI_ALREADY_INITIALIZED = 0x00000191
+CK_TRUE = 1
 CKF_RW_SESSION = (1 << 1)
 CKF_SERIAL_SESSION = (1 << 2)
+CKF_OS_LOCKING_OK = 0x02
 CKU_SO = 0
 CKU_USER = 1
 
@@ -134,13 +138,15 @@ CKA_SUPPORTED_CMS_ATTRIBUTES = 0x503
 CKM_SHA256_HMAC = 0x251
 CKM_AES_KEY_GEN = 0x1080
 CKM_AES_CBC = 0x1082
+CKM_AES_MAC = 0x1083
 CKM_AES_CBC_PAD = 0x1085
 CKM_AES_GCM = 0x1087
-CKM_AES_KEY_WRAP = 0x1090
+CKM_AES_KEY_WRAP_PAD = 0x210A
+CKM_AES_KEY_WRAP_KWP = 0x210B
 CKM_GENERIC_SECRET_KEY_GEN = 0x350
 VENDOR_SAFENET_CKM_AES_GCM = 0x8000011c
 
-# Thales Vendor-defined Mechanisms
+# nCipher Vendor-defined Mechanisms
 CKM_NC_SHA256_HMAC_KEY_GEN = 0xDE436997
 
 _ENCRYPTION_MECHANISMS = {
@@ -152,14 +158,31 @@ _ENCRYPTION_MECHANISMS = {
 _CBC_IV_SIZE = 16  # bytes
 _CBC_BLOCK_SIZE = 128  # bits
 
+# ----- Supported Mechanisms -----
+# Barbican only supports the PKCS#11 mechanisms below
+
 _KEY_GEN_MECHANISMS = {
     'CKM_AES_KEY_GEN': CKM_AES_KEY_GEN,
-    'CKM_NC_SHA256_HMAC_KEY_GEN': CKM_NC_SHA256_HMAC_KEY_GEN
+    'CKM_NC_SHA256_HMAC_KEY_GEN': CKM_NC_SHA256_HMAC_KEY_GEN,
+    'CKM_GENERIC_SECRET_KEY_GEN': CKM_GENERIC_SECRET_KEY_GEN,
+}
+
+_HMAC_MECHANISMS = {
+    'CKM_SHA256_HMAC': CKM_SHA256_HMAC,
+    'CKM_AES_MAC': CKM_AES_MAC
+}
+
+_KEY_WRAP_MECHANISMS = {
+    'CKM_AES_CBC_PAD': CKM_AES_CBC_PAD,
+    'CKM_AES_KEY_WRAP_PAD': CKM_AES_KEY_WRAP_PAD,
+    'CKM_AES_KEY_WRAP_KWP': CKM_AES_KEY_WRAP_KWP
 }
 
 CKM_NAMES = dict()
 CKM_NAMES.update(_ENCRYPTION_MECHANISMS)
 CKM_NAMES.update(_KEY_GEN_MECHANISMS)
+CKM_NAMES.update(_HMAC_MECHANISMS)
+CKM_NAMES.update(_KEY_WRAP_MECHANISMS)
 
 ERROR_CODES = {
     1: 'CKR_CANCEL',
@@ -246,7 +269,9 @@ ERROR_CODES = {
     0x1a0: 'CKR_MUTEX_BAD',
     0x1a1: 'CKR_MUTEX_NOT_LOCKED',
     0x200: 'CKR_FUNCTION_REJECTED',
-    1 << 31: 'CKR_VENDOR_DEFINED'
+    1 << 31: 'CKR_VENDOR_DEFINED',
+    # Trustway Proteccio Codes
+    0x81000071: 'EHOSTUNREACH'
 }
 
 
@@ -254,15 +279,21 @@ def build_ffi():
     ffi = cffi.FFI()
     ffi.cdef(textwrap.dedent("""
     typedef unsigned char CK_BYTE;
+    typedef CK_BYTE CK_CHAR;
+    typedef CK_BYTE CK_UTF8CHAR;
+    typedef CK_BYTE CK_BBOOL;
     typedef unsigned long CK_ULONG;
     typedef unsigned long CK_RV;
     typedef unsigned long CK_SESSION_HANDLE;
     typedef unsigned long CK_OBJECT_HANDLE;
     typedef unsigned long CK_SLOT_ID;
+    typedef CK_SLOT_ID * CK_SLOT_ID_PTR;
     typedef unsigned long CK_FLAGS;
     typedef unsigned long CK_STATE;
     typedef unsigned long CK_USER_TYPE;
     typedef unsigned char * CK_UTF8CHAR_PTR;
+    typedef void * CK_VOID_PTR;
+    typedef CK_VOID_PTR * CK_VOID_PTR_PTR;
     typedef ... *CK_NOTIFY;
 
     typedef unsigned long ck_attribute_type_t;
@@ -274,6 +305,20 @@ def build_ffi():
     typedef struct ck_attribute CK_ATTRIBUTE;
     typedef CK_ATTRIBUTE *CK_ATTRIBUTE_PTR;
 
+    typedef CK_RV (*CK_CREATEMUTEX)(CK_VOID_PTR_PTR);
+    typedef CK_RV (*CK_DESTROYMUTEX)(CK_VOID_PTR);
+    typedef CK_RV (*CK_LOCKMUTEX)(CK_VOID_PTR);
+    typedef CK_RV (*CK_UNLOCKMUTEX)(CK_VOID_PTR);
+
+    typedef struct CK_C_INITIALIZE_ARGS {
+        CK_CREATEMUTEX CreateMutex;
+        CK_DESTROYMUTEX DestroyMutex;
+        CK_LOCKMUTEX LockMutex;
+        CK_UNLOCKMUTEX UnlockMutex;
+        CK_FLAGS flags;
+        CK_VOID_PTR pReserved;
+    } CK_C_INITIALIZE_ARGS;
+
     typedef unsigned long ck_mechanism_type_t;
     struct ck_mechanism {
         ck_mechanism_type_t mechanism;
@@ -285,6 +330,54 @@ def build_ffi():
     typedef CK_BYTE *CK_BYTE_PTR;
     typedef CK_ULONG *CK_ULONG_PTR;
 
+    typedef struct CK_VERSION {
+        CK_BYTE major;
+        CK_BYTE minor;
+    } CK_VERSION;
+
+    typedef struct CK_INFO {
+        CK_VERSION  cryptokiVersion;
+        CK_UTF8CHAR manufacturerID[32];
+        CK_FLAGS flags;
+        CK_UTF8CHAR libraryDescription[32];
+        CK_VERSION  libraryVersion;
+    } CK_INFO;
+
+    typedef CK_INFO * CK_INFO_PTR;
+
+    typedef struct CK_SLOT_INFO {
+        CK_UTF8CHAR slotDescription[64];
+        CK_UTF8CHAR manufacturerID[32];
+        CK_FLAGS    flags;
+
+        CK_VERSION  hardwareVersion;
+        CK_VERSION  firmwareVersion;
+    } CK_SLOT_INFO;
+    typedef CK_SLOT_INFO * CK_SLOT_INFO_PTR;
+
+    typedef struct CK_TOKEN_INFO {
+        CK_UTF8CHAR label[32];
+        CK_UTF8CHAR manufacturerID[32];
+        CK_UTF8CHAR model[16];
+        CK_CHAR serialNumber[16];
+        CK_FLAGS flags;
+
+        CK_ULONG ulMaxSessionCount;
+        CK_ULONG ulSessionCount;
+        CK_ULONG ulMaxRwSessionCount;
+        CK_ULONG ulRwSessionCount;
+        CK_ULONG ulMaxPinLen;
+        CK_ULONG ulMinPinLen;
+        CK_ULONG ulTotalPublicMemory;
+        CK_ULONG ulFreePublicMemory;
+        CK_ULONG ulTotalPrivateMemory;
+        CK_ULONG ulFreePrivateMemory;
+        CK_VERSION hardwareVersion;
+        CK_VERSION firmwareVersion;
+        CK_CHAR utcTime[16];
+    } CK_TOKEN_INFO;
+    typedef CK_TOKEN_INFO * CK_TOKEN_INFO_PTR;
+
     typedef struct ck_session_info {
         CK_SLOT_ID slot_id;
         CK_STATE state;
@@ -312,6 +405,10 @@ def build_ffi():
     CK_RV C_GetSessionInfo(CK_SESSION_HANDLE, CK_SESSION_INFO_PTR);
     CK_RV C_Login(CK_SESSION_HANDLE, CK_USER_TYPE, CK_UTF8CHAR_PTR,
                   CK_ULONG);
+    CK_RV C_GetInfo(CK_INFO_PTR);
+    CK_RV C_GetSlotList(CK_BBOOL, CK_SLOT_ID_PTR, CK_ULONG_PTR);
+    CK_RV C_GetSlotInfo(CK_SLOT_ID, CK_SLOT_INFO_PTR);
+    CK_RV C_GetTokenInfo(CK_SLOT_ID, CK_TOKEN_INFO_PTR);
     CK_RV C_GetAttributeValue(CK_SESSION_HANDLE, CK_OBJECT_HANDLE,
                               CK_ATTRIBUTE *, CK_ULONG);
     CK_RV C_SetAttributeValue(CK_SESSION_HANDLE, CK_OBJECT_HANDLE,
@@ -351,39 +448,54 @@ def build_ffi():
 
 
 class PKCS11(object):
-    def __init__(self, library_path, login_passphrase, rw_session, slot_id,
-                 encryption_mechanism=None,
-                 ffi=None, algorithm=None,
+    def __init__(self, library_path, login_passphrase,
+                 token_serial_number=None,
+                 token_labels=None,
+                 slot_id=None,
+                 rw_session=True,
                  seed_random_buffer=None,
-                 generate_iv=None):
-        if algorithm:
-            LOG.warning("WARNING: Using deprecated 'algorithm' argument.")
-            encryption_mechanism = encryption_mechanism or algorithm
-
+                 encryption_mechanism=None,
+                 encryption_gen_iv=True,
+                 always_set_cka_sensitive=True,
+                 hmac_mechanism=None,
+                 key_wrap_mechanism=None,
+                 key_wrap_gen_iv=False,
+                 os_locking_ok=False,
+                 ffi=None):
+        # Validate all mechanisms are supported
         if encryption_mechanism not in _ENCRYPTION_MECHANISMS:
-            raise ValueError("Invalid encryption_mechanism.")
-        self.encrypt_mech = _ENCRYPTION_MECHANISMS[encryption_mechanism]
+            raise ValueError("Invalid Encryption mechanism.")
+        if hmac_mechanism not in _HMAC_MECHANISMS:
+            raise ValueError("Invalid HMAC signing mechanism.")
+        if key_wrap_mechanism not in _KEY_WRAP_MECHANISMS:
+            raise ValueError("Invalid Key Wrapping mechanism.")
+
+        self.ffi = ffi or build_ffi()
+        self.lib = self.ffi.dlopen(library_path)
+        self._initialize_library(os_locking_ok)
+
+        # Session options
+        self.login_passphrase = _to_bytes(login_passphrase)
+        self.rw_session = rw_session
+        self.slot_id = self._get_slot_id(
+            token_serial_number,
+            token_labels,
+            slot_id)
+
+        # Algorithm options
+        self.encrypt_mech = CKM_NAMES[encryption_mechanism]
         self.encrypt = getattr(
             self,
             '_{}_encrypt'.format(encryption_mechanism)
         )
-
-        self.ffi = ffi or build_ffi()
-        self.lib = self.ffi.dlopen(library_path)
-        rv = self.lib.C_Initialize(self.ffi.NULL)
-        self._check_error(rv)
-
-        # Session options
-        self.login_passphrase = login_passphrase
-        self.rw_session = rw_session
-        self.slot_id = slot_id
-
-        # Algorithm options
-        self.algorithm = CKM_NAMES[encryption_mechanism]
+        self.encrypt_gen_iv = encryption_gen_iv
         self.blocksize = 16
         self.noncesize = 12
         self.gcmtagsize = 16
-        self.generate_iv = generate_iv
+        self.always_set_cka_sensitive = always_set_cka_sensitive
+        self.hmac_mechanism = CKM_NAMES[hmac_mechanism]
+        self.key_wrap_mechanism = key_wrap_mechanism
+        self.key_wrap_gen_iv = key_wrap_gen_iv
 
         # Validate configuration and RNG
         session = self.get_session()
@@ -391,6 +503,80 @@ class PKCS11(object):
             self._seed_random(session, seed_random_buffer)
         self._rng_self_test(session)
         self.return_session(session)
+        LOG.debug("Connected to PCKS#11 Token in Slot %s", self.slot_id)
+
+    def _initialize_library(self, os_locking_ok):
+        if os_locking_ok:
+            init_arg_pt = self.ffi.new("CK_C_INITIALIZE_ARGS *")
+            init_arg_pt.flags = CKF_OS_LOCKING_OK
+        else:
+            init_arg_pt = self.ffi.NULL
+
+        rv = self.lib.C_Initialize(init_arg_pt)
+        self._check_error(rv)
+
+    def _get_slot_id(self, token_serial_number, token_labels, slot_id):
+        # First find out how many slots with tokens are available
+        slots_ptr = self.ffi.new("CK_ULONG_PTR")
+        rv = self.lib.C_GetSlotList(CK_TRUE, self.ffi.NULL, slots_ptr)
+        self._check_error(rv)
+
+        # Next get the Slot IDs for each of the available slots
+        slot_ids_ptr = self.ffi.new("CK_SLOT_ID[{}]".format(slots_ptr[0]))
+        rv = self.lib.C_GetSlotList(CK_TRUE, slot_ids_ptr, slots_ptr)
+        self._check_error(rv)
+
+        # Gather details from each token
+        tokens = list()
+        for id in slot_ids_ptr:
+            token_info_ptr = self.ffi.new("CK_TOKEN_INFO_PTR")
+            rv = self.lib.C_GetTokenInfo(id, token_info_ptr)
+            self._check_error(rv)
+            token = Token(
+                id,
+                self.ffi.string(token_info_ptr.label).decode("UTF-8").strip(),
+                self.ffi.string(
+                    token_info_ptr.serialNumber
+                ).decode("UTF-8").strip()
+            )
+            LOG.debug("Slot %s: label: %s sn: %s",
+                      token.slot_id,
+                      token.label,
+                      token.serial_number)
+            tokens.append(token)
+
+        # Matching serial number gets highest priority
+        if token_serial_number:
+            for token in tokens:
+                if token.serial_number == token_serial_number:
+                    LOG.debug("Found token sn: %s in slot %s",
+                              token.serial_number,
+                              token.slot_id)
+                    if token_labels:
+                        LOG.warning(
+                            "Ignoring token_labels: %s from barbican.conf",
+                            token_labels
+                        )
+                    if slot_id:
+                        LOG.warning("Ignoring slot_id: %s from barbican.conf",
+                                    slot_id)
+                    return token.slot_id
+            raise ValueError("Token Serial Number not found.")
+
+        # Label match is next, raises an error if there's not exactly one match
+        if token_labels:
+            for token in tokens:
+                if token.label in token_labels:
+                    LOG.debug("Found token label: %s in slot %s", token.label,
+                              token.slot_id)
+                    if slot_id:
+                        LOG.warning("Ignoring slot_id: %s from barbican.conf",
+                                    slot_id)
+                    return token.slot_id
+            raise ValueError("Token Labels not found.")
+
+        # If we got this far, slot_id was the only param given, so we return it
+        return slot_id
 
     def get_session(self):
         session = self._open_session(self.slot_id)
@@ -482,14 +668,14 @@ class PKCS11(object):
 
     def _VENDOR_SAFENET_CKM_AES_GCM_encrypt(self, key, pt_data, session):
         iv = None
-        if self.generate_iv:
+        if self.encrypt_gen_iv:
             iv = self._generate_random(self.noncesize, session)
         ck_mechanism = self._build_gcm_mechanism(iv)
         rv = self.lib.C_EncryptInit(session, ck_mechanism.mech, key)
         self._check_error(rv)
 
         pt_len = len(pt_data)
-        if self.generate_iv:
+        if self.encrypt_gen_iv:
             ct_len = self.ffi.new("CK_ULONG *", pt_len + self.gcmtagsize)
         else:
             ct_len = self.ffi.new("CK_ULONG *", pt_len + self.gcmtagsize * 2)
@@ -497,11 +683,11 @@ class PKCS11(object):
         rv = self.lib.C_Encrypt(session, pt_data, pt_len, ct, ct_len)
         self._check_error(rv)
 
-        if self.generate_iv:
+        if self.encrypt_gen_iv:
             return {
                 "iv": self.ffi.buffer(iv)[:],
                 "ct": self.ffi.buffer(ct, ct_len[0])[:]
-                }
+            }
         else:
             # HSM-generated IVs are appended to the end of the ciphertext
             return {
@@ -511,7 +697,7 @@ class PKCS11(object):
 
     def _build_gcm_mechanism(self, iv=None):
         mech = self.ffi.new("CK_MECHANISM *")
-        mech.mechanism = self.algorithm
+        mech.mechanism = self.encrypt_mech
         gcm = self.ffi.new("CK_AES_GCM_PARAMS *")
 
         if iv:
@@ -560,7 +746,9 @@ class PKCS11(object):
         return self._VENDOR_SAFENET_CKM_AES_GCM_encrypt(key, pt_data, session)
 
     def _CKM_AES_GCM_decrypt(self, key, iv, ct_data, session):
-        return self._VENDOR_SAFENET_CKM_AES_GCM_decrypt(key, ct_data, session)
+        return self._VENDOR_SAFENET_CKM_AES_GCM_decrypt(
+            key, iv, ct_data, session
+        )
 
     def decrypt(self, mechanism, key, iv, ct_data, session):
         if mechanism not in _ENCRYPTION_MECHANISMS:
@@ -580,7 +768,7 @@ class PKCS11(object):
         token = master_key
         extractable = not master_key
         # in some HSMs extractable keys cannot be marked sensitive
-        sensitive = not extractable
+        sensitive = self.always_set_cka_sensitive or not extractable
 
         ck_attributes = [
             Attribute(CKA_CLASS, CKO_SECRET_KEY),
@@ -614,11 +802,19 @@ class PKCS11(object):
         return obj_handle_ptr[0]
 
     def wrap_key(self, wrapping_key, key_to_wrap, session):
-        mech = self.ffi.new("CK_MECHANISM *")
-        mech.mechanism = CKM_AES_CBC_PAD
-        iv = self._generate_random(16, session)
-        mech.parameter = iv
-        mech.parameter_len = 16
+        if self.key_wrap_gen_iv:
+            iv_len = {
+                'CKM_AES_CBC_PAD': 16,  # bytes
+                'CKM_AES_KEY_WRAP_PAD': 8,  # bytes
+                'CKM_AES_KEY_WRAP_KWP': 4   # bytes
+            }.get(self.key_wrap_mechanism)
+            iv = self._generate_random(iv_len, session)
+        else:
+            iv = None
+        mech = self._build_key_wrap_mechanism(
+            CKM_NAMES[self.key_wrap_mechanism],
+            iv
+        )
 
         # Ask for length of the wrapped key
         wrapped_key_len = self.ffi.new("CK_ULONG *")
@@ -637,18 +833,27 @@ class PKCS11(object):
         self._check_error(rv)
 
         return {
-            'iv': self.ffi.buffer(iv)[:],
-            'wrapped_key': self.ffi.buffer(wrapped_key, wrapped_key_len[0])[:]
+            'iv': iv and self.ffi.buffer(iv)[:],
+            'wrapped_key': self.ffi.buffer(wrapped_key, wrapped_key_len[0])[:],
+            'key_wrap_mechanism': self.key_wrap_mechanism
         }
 
-    def unwrap_key(self, wrapping_key, iv, wrapped_key, session):
-        ck_iv = self.ffi.new("CK_BYTE[]", iv)
-        ck_wrapped_key = self.ffi.new("CK_BYTE[]", wrapped_key)
-        unwrapped_key = self.ffi.new("CK_OBJECT_HANDLE *")
+    def _build_key_wrap_mechanism(self, mechanism, iv):
         mech = self.ffi.new("CK_MECHANISM *")
-        mech.mechanism = CKM_AES_CBC_PAD
-        mech.parameter = ck_iv
-        mech.parameter_len = len(iv)
+        mech.mechanism = mechanism
+        if iv is not None:
+            mech.parameter = iv
+            mech.parameter_len = len(iv)
+        return mech
+
+    def unwrap_key(self, mechanism, wrapping_key, iv, wrapped_key, session):
+        ck_wrapped_key = self.ffi.new("CK_BYTE[]", wrapped_key)
+        ck_iv = iv and self.ffi.new("CK_BYTE[{}]".format(len(iv)), iv)
+        unwrapped_key = self.ffi.new("CK_OBJECT_HANDLE *")
+        mech = self._build_key_wrap_mechanism(
+            CKM_NAMES[mechanism],
+            ck_iv
+        )
 
         ck_attributes = self._build_attributes([
             Attribute(CKA_CLASS, CKO_SECRET_KEY),
@@ -670,7 +875,7 @@ class PKCS11(object):
 
     def compute_hmac(self, hmac_key, data, session):
         mech = self.ffi.new("CK_MECHANISM *")
-        mech.mechanism = CKM_SHA256_HMAC
+        mech.mechanism = self.hmac_mechanism
         rv = self.lib.C_SignInit(session, mech, hmac_key)
         self._check_error(rv)
 
@@ -683,7 +888,7 @@ class PKCS11(object):
 
     def verify_hmac(self, hmac_key, sig, data, session):
         mech = self.ffi.new("CK_MECHANISM *")
-        mech.mechanism = CKM_SHA256_HMAC
+        mech.mechanism = self.hmac_mechanism
 
         rv = self.lib.C_VerifyInit(session, mech, hmac_key)
         self._check_error(rv)
@@ -698,16 +903,23 @@ class PKCS11(object):
 
     def finalize(self):
         rv = self.lib.C_Finalize(self.ffi.NULL)
-        self._check_error(rv)
+        try:
+            self._check_error(rv)
+        except exception.TrustwayProteccioException:
+            LOG.warning("Trustway Proteccio client failed to finalize.")
 
     def _check_error(self, value):
-        if value != CKR_OK:
+        if value != CKR_OK and value != CKR_CRYPTOKI_ALREADY_INITIALIZED:
             code = ERROR_CODES.get(value, 'CKR_????')
             hex_code = "{hex} {code}".format(hex=hex(value), code=code)
 
             if code == 'CKR_TOKEN_NOT_PRESENT':
                 raise exception.P11CryptoTokenException(slot_id=self.slot_id)
 
+            if code == 'EHOSTUNREACH':
+                raise exception.TrustwayProteccioException(
+                    "Trustway Proteccio Error: {code}".format(code=hex_code))
+
             raise exception.P11CryptoPluginException(u._(
                 "HSM returned response code: {code}").format(code=hex_code))
 
@@ -779,3 +991,10 @@ class PKCS11(object):
         if test_random == b'\x00' * 100:
             raise exception.P11CryptoPluginException(
                 u._("Apparent RNG self-test failure."))
+
+
+def _to_bytes(string):
+    if isinstance(string, bytes):
+        return string
+    else:
+        return string.encode('UTF-8')
