@@ -17,6 +17,7 @@ import datetime
 from unittest import mock
 
 from oslo_db import exception as db_exc
+from oslo_utils import timeutils
 from sqlalchemy.exc import IntegrityError
 
 from barbican.model import clean
@@ -237,7 +238,7 @@ class WhenTestingDBCleanUpCommand(utils.RepositoryTestCase):
         """Test cleaning up entries within date"""
         secret = _setup_entry('secret', project=project)
         order = order = _setup_entry('order', project=project, secret=secret)
-        current_time = datetime.datetime.utcnow()
+        current_time = timeutils.utcnow()
         tomorrow = current_time + datetime.timedelta(days=1)
         yesterday = current_time - datetime.timedelta(days=1)
         secret.delete()
@@ -261,7 +262,7 @@ class WhenTestingDBCleanUpCommand(utils.RepositoryTestCase):
     def test_soft_deleting_expired_secrets(self, project):
         """Test soft deleting secrets that are expired"""
 
-        current_time = datetime.datetime.utcnow()
+        current_time = timeutils.utcnow()
         tomorrow = current_time + datetime.timedelta(days=1)
         yesterday = current_time - datetime.timedelta(days=1)
 
@@ -363,11 +364,11 @@ class WhenTestingDBCleanUpCommand(utils.RepositoryTestCase):
                             test_log_file)
         set_calls = [mock.call('debug', True),
                      mock.call('log_file', test_log_file),
-                     mock.call('sql_connection', test_sql_url)]
+                     mock.call('connection', test_sql_url, 'database')]
         mock_conf.set_override.assert_has_calls(set_calls)
 
         clear_calls = [mock.call('debug'), mock.call('log_file'),
-                       mock.call('sql_connection')]
+                       mock.call('connection', 'database')]
         mock_conf.clear_override.assert_has_calls(clear_calls)
         self.assertTrue(mock_repo.setup_database_engine_and_factory.called)
         self.assertTrue(mock_repo.commit.called)
