@@ -1455,70 +1455,6 @@ class WhenTestingProjectQuotasValidator(utils.BaseTestCase):
                           self.good_project_quotas)
 
 
-@utils.parameterized_test_case
-class WhenTestingNewCAValidator(utils.BaseTestCase):
-
-    def setUp(self):
-        super(WhenTestingNewCAValidator, self).setUp()
-
-        self.new_ca_req = {'name': 'New CA',
-                           'subject_dn': 'cn=barbican-server,o=example.com',
-                           'parent_ca_ref':
-                               'https://localhost/v1/cas/parent_ca_id',
-                           'description': 'This is a subCA'}
-
-        self.validator = validators.NewCAValidator()
-
-    def test_should_raise_with_empty_data(self):
-        self.assertRaises(
-            excep.InvalidObject,
-            self.validator.validate,
-            {}
-        )
-
-    @utils.parameterized_dataset({
-        'name': ['name'],
-        'subject_dn': ['subject_dn'],
-        'parent_ca_ref': ['parent_ca_ref'],
-    })
-    def should_raise_if_any_required_parameter_is_missing(self, parameter):
-        del self.new_ca_req[parameter]
-        exception = self.assertRaises(
-            excep.InvalidObject,
-            self.validator.validate,
-            self.new_ca_req
-        )
-
-        self.assertEqual(parameter, exception.invalid_property)
-
-    @utils.parameterized_dataset({
-        'name': ['name'],
-        'subject_dn': ['subject_dn'],
-        'parent_ca_ref': ['parent_ca_ref'],
-    })
-    def should_raise_if_any_required_parameter_is_empty(self, parameter):
-        self.new_ca_req[parameter] = ''
-        exception = self.assertRaises(
-            excep.InvalidObject,
-            self.validator.validate,
-            self.new_ca_req
-        )
-
-        self.assertEqual(parameter, exception.invalid_property)
-
-    def test_should_pass_with_valid_data(self):
-        self.validator.validate(self.new_ca_req)
-
-    def test_should_raise_with_invalid_subject_dn(self):
-        self.new_ca_req['subject_dn'] = 'I am an invalid subject_dn!'
-
-        self.assertRaises(
-            excep.InvalidSubjectDN,
-            self.validator.validate,
-            self.new_ca_req
-        )
-
-
 @utils.parameterized_test_case
 class WhenTestingSecretMetadataValidator(utils.BaseTestCase):
 
