@@ -14,13 +14,13 @@
 # limitations under the License.
 
 import datetime
-from oslo_serialization import base64 as oslo_base64
-from oslo_serialization import jsonutils
-import six
 import sys
-import testtools
 import time
 
+from oslo_serialization import base64 as oslo_base64
+from oslo_serialization import jsonutils as json
+from oslo_utils import timeutils
+import testtools
 from testtools import testcase
 
 from barbican.plugin.interface import secret_store as ss
@@ -84,7 +84,7 @@ def get_passphrase_req():
 def get_default_data():
     return {
         "name": "AES key",
-        "expiration": "2020-02-28T19:14:44.180394",
+        "expiration": "2030-02-28T19:14:44.180394",
         "algorithm": "aes",
         "bit_length": 256,
         "mode": "cbc",
@@ -135,7 +135,7 @@ class SecretsTestCase(base.TestCase):
 
         self.default_secret_create_two_phase_data = {
             "name": "AES key",
-            "expiration": "2020-02-28T19:14:44.180394",
+            "expiration": "2030-02-28T19:14:44.180394",
             "algorithm": "aes",
             "bit_length": 256,
             "mode": "cbc",
@@ -465,7 +465,7 @@ class SecretsTestCase(base.TestCase):
 
         Launchpad bug #1315498
         """
-        data = u'\U0001F37A'
+        data = '\U0001F37A'
         data = data.encode('utf-8')
         test_model = secret_models.SecretModel(
             **self.default_secret_create_two_phase_data)
@@ -512,7 +512,7 @@ class SecretsTestCase(base.TestCase):
         # first, ensure that the return code is 400
         self.assertEqual(400, resp.status_code)
 
-        resp_dict = jsonutils.loads(resp.content)
+        resp_dict = json.loads(resp.content)
 
         self.assertIn(
             "Provided object does not match schema 'Secret': "
@@ -705,14 +705,13 @@ class SecretsTestCase(base.TestCase):
             'payload_content_type': 'text/plain',
             'payload_content_encoding': None},
 
-        # TODO(dmend): Fix content negotiation
-        # 'utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain; charset=utf-8',
-        #    'payload_content_encoding': None},
+        'utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain; charset=utf-8',
+            'payload_content_encoding': None},
 
-        # 'no_space_utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain;charset=utf-8',
-        #    'payload_content_encoding': None},
+        'no_space_utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain;charset=utf-8',
+            'payload_content_encoding': None},
 
         'octet_content_type_base64_encoding': {
             'payload_content_type': 'application/octet-stream',
@@ -747,14 +746,13 @@ class SecretsTestCase(base.TestCase):
             'payload_content_type': 'text/plain',
             'payload_content_encoding': None},
 
-        # TODO(dmend): Fix content negotiation
-        # 'utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain; charset=utf-8',
-        #    'payload_content_encoding': None},
+        'utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain; charset=utf-8',
+            'payload_content_encoding': None},
 
-        # 'no_space_utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain;charset=utf-8',
-        #    'payload_content_encoding': None},
+        'no_space_utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain;charset=utf-8',
+            'payload_content_encoding': None},
 
         'octet_content_type_base64_encoding': {
             'payload_content_type': 'application/octet-stream',
@@ -884,8 +882,8 @@ class SecretsTestCase(base.TestCase):
         'array': [['boom']],
         'int': [123],
         'none': [None],
-        'bad_character': [six.unichr(0x0080)],
-        'bad_characters': [six.unichr(0x1111) + six.unichr(0xffff)]
+        'bad_character': [chr(0x0080)],
+        'bad_characters': [chr(0x1111) + chr(0xffff)]
     })
     @testcase.attr('negative')
     def test_secret_create_defaults_invalid_payload(self, payload):
@@ -1034,21 +1032,21 @@ class SecretsTestCase(base.TestCase):
 
     @utils.parameterized_dataset({
         'invalid_http_content_type_characaters_latin': {
-            'http_content_type': u'\u00c4'.encode('utf-8')},
+            'http_content_type': '\u00c4'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_arabic': {
-            'http_content_type': u'\u060f'.encode('utf-8')},
+            'http_content_type': '\u060f'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_cyrillic': {
-            'http_content_type': u'\u0416'.encode('utf-8')},
+            'http_content_type': '\u0416'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_replacement_character': {
-            'http_content_type': u'\ufffd'.encode('utf-8')},
+            'http_content_type': '\ufffd'.encode('utf-8')},
     })
     @testcase.attr('negative')
     def test_secret_create_with_invalid_http_content_type_characters(
             self, http_content_type):
-        """Attempt to create secrets with invalid unicode characters in the
+        """Create secrets with invalid unicode characters in the
 
         HTTP request's Content-Type header. Should return a 415.
         """
@@ -1062,21 +1060,21 @@ class SecretsTestCase(base.TestCase):
 
     @utils.parameterized_dataset({
         'invalid_http_content_type_characaters_latin': {
-            'payload_content_type': u'\u00c4'.encode('utf-8')},
+            'payload_content_type': '\u00c4'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_arabic': {
-            'payload_content_type': u'\u060f'.encode('utf-8')},
+            'payload_content_type': '\u060f'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_cyrillic': {
-            'payload_content_type': u'\u0416'.encode('utf-8')},
+            'payload_content_type': '\u0416'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_replacement_character': {
-            'payload_content_type': u'\ufffd'.encode('utf-8')},
+            'payload_content_type': '\ufffd'.encode('utf-8')},
     })
     @testcase.attr('negative')
     def test_secret_create_with_invalid_payload_content_type_characters(
             self, payload_content_type):
-        """Attempt to create secrets with non-ascii characters in the
+        """Create secrets with non-ascii characters in the
 
         payload's content type attribute. Should return a 400.
         """
@@ -1154,10 +1152,8 @@ class ListingSecretsTestCase(base.TestCase):
     })
     @testcase.attr('positive')
     def test_secret_list_with_date_filter(self, date_type):
-        expiration_1 = str(
-            datetime.datetime.utcnow() + datetime.timedelta(days=3))
-        expiration_2 = str(
-            datetime.datetime.utcnow() + datetime.timedelta(days=5))
+        expiration_1 = str(timeutils.utcnow() + datetime.timedelta(days=3))
+        expiration_2 = str(timeutils.utcnow() + datetime.timedelta(days=5))
 
         two_phase_model = secret_models.SecretModel(expiration=expiration_1)
         resp, secret_ref_1 = self.behaviors.create_secret(two_phase_model)
@@ -1297,7 +1293,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_create_unauthed_no_proj_id(self):
-        """Attempt to create a secret without a token or project id
+        """Create a secret without a token or project id
 
         Should return 401
         """
@@ -1308,7 +1304,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_create_unauthed_fake_proj_id(self):
-        """Attempt to create a secret with a project id but no token
+        """Create a secret with a project id but no token
 
         Should return 401
         """
@@ -1322,7 +1318,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_create_unauthed_real_proj_id(self):
-        """Attempt to create a secret with a project id but no token
+        """Create a secret with a project id but no token
 
         Should return 401
         """
@@ -1336,7 +1332,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_get_unauthed_no_proj_id_fake_secret(self):
-        """Attempt to read a non-existant secret without a token or project id
+        """Read a non-existant secret without a token or project id
 
         Should return 401
         """
@@ -1350,7 +1346,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_get_unauthed_no_proj_id_real_secret(self):
-        """Attempt to read an existing secret without a token or project id
+        """Read an existing secret without a token or project id
 
         Should return 401
         """
@@ -1364,7 +1360,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_get_unauthed_fake_proj_id_fake_secret(self):
-        """Attempt to get a non-existant secret with a project id but no token
+        """Get a non-existant secret with a project id but no token
 
         Should return 401
         """
@@ -1380,7 +1376,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_get_unauthed_fake_proj_id_real_secret(self):
-        """Attempt to get an existing secret with a project id but no token
+        """Get an existing secret with a project id but no token
 
         Should return 401
         """
@@ -1396,7 +1392,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_get_unauthed_real_proj_id_fake_secret(self):
-        """Attempt to get a non-existant secret with a project id but no token
+        """Get a non-existant secret with a project id but no token
 
         Should return 401
         """
@@ -1412,7 +1408,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_get_unauthed_real_proj_id_real_secret(self):
-        """Attempt to get an existing secret with a project id but no token
+        """Get an existing secret with a project id but no token
 
         Should return 401
         """
@@ -1428,7 +1424,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_put_unauthed_no_proj_id_fake_secret(self):
-        """Attempt to update a non-existant secret without a token or project id
+        """Update a non-existant secret without a token or project id
 
         Should return 401
         """
@@ -1442,7 +1438,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_put_unauthed_no_proj_id_real_secret(self):
-        """Attempt to update an existing secret without a token or project id
+        """Update an existing secret without a token or project id
 
         Should return 401
         """
@@ -1456,7 +1452,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_put_unauthed_fake_proj_id_fake_secret(self):
-        """Attempt to update a non-existant secret with a project id, but no token
+        """Update a non-existant secret with a project id, but no token
 
         Should return 401
         """
@@ -1472,7 +1468,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_put_unauthed_fake_proj_id_real_secret(self):
-        """Attempt to update an existing secret with a project id, but no token
+        """Update an existing secret with a project id, but no token
 
         Should return 401
         """
@@ -1488,7 +1484,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_put_unauthed_real_proj_id_fake_secret(self):
-        """Attempt to update a non-existant secret with a project id, but no token
+        """Update a non-existant secret with a project id, but no token
 
         Should return 401
         """
@@ -1504,7 +1500,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_put_unauthed_real_proj_id_real_secret(self):
-        """Attempt to update an existing secret with a project id, but no token
+        """Update an existing secret with a project id, but no token
 
         Should return 401
         """
@@ -1520,7 +1516,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_delete_unauthed_no_proj_id_fake_secret(self):
-        """Attempt to delete a non-existant secret without a token or project id
+        """Delete a non-existant secret without a token or project id
 
         Should return 401
         """
@@ -1532,7 +1528,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_delete_unauthed_no_proj_id_real_secret(self):
-        """Attempt to delete an existing secret without a token or project id
+        """Delete an existing secret without a token or project id
 
         Should return 401
         """
@@ -1544,7 +1540,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_delete_unauthed_fake_proj_id_fake_secret(self):
-        """Attempt to delete a non-existant secret with a project id, but no token
+        """Delete a non-existant secret with a project id, but no token
 
         Should return 401
         """
@@ -1558,7 +1554,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_delete_unauthed_fake_proj_id_real_secret(self):
-        """Attempt to delete an existing secret with a project id, but no token
+        """Delete an existing secret with a project id, but no token
 
         Should return 401
         """
@@ -1572,7 +1568,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_delete_unauthed_real_proj_id_fake_secret(self):
-        """Attempt to delete a non-existant secret with a project id, but no token
+        """Delete a non-existant secret with a project id, but no token
 
         Should return 401
         """
@@ -1586,7 +1582,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
     @testcase.attr('negative', 'security')
     def test_secret_delete_unauthed_real_proj_id_real_secret(self):
-        """Attempt to delete an existing secret with a project id, but no token
+        """Delete an existing secret with a project id, but no token
 
         Should return 401
         """
@@ -1609,18 +1605,23 @@ class SecretsMultipleBackendTestCase(base.TestCase):
             self.client)
         self.default_secret_create_data = get_default_data()
         if base.conf_multiple_backends_enabled:
+            # set preferred secret store for admin_a (project a) user
+            # and don't set preferred secret store for admin_b (project b) user
             resp, stores = self.ss_behaviors.get_all_secret_stores(
                 user_name=admin_a)
             self.assertEqual(200, resp.status_code)
-            secret_store_ref = None
-            for store in stores['secret-stores']:
-                if not store['global_default']:
-                    secret_store_ref = store['secret_store_ref']
+            global_ss = None
+            first_non_global_ss = None
+            for store in stores['secret_stores']:
+                if store['global_default']:
+                    global_ss = store['secret_store_ref']
+                else:
+                    first_non_global_ss = store['secret_store_ref']
                     break
-            # set preferred secret store for admin_a (project a) user
-            # and don't set preferred secret store for admin_b (project b) user
-            self.ss_behaviors.set_preferred_secret_store(secret_store_ref,
-                                                         user_name=admin_a)
+            self.ss_behaviors.set_preferred_secret_store(
+                first_non_global_ss or global_ss,
+                user_name=admin_a
+            )
 
     def tearDown(self):
         self.behaviors.delete_all_created_secrets()
@@ -1637,61 +1638,61 @@ class SecretsMultipleBackendTestCase(base.TestCase):
             'symmetric',
             oslo_base64.decode_as_bytes(get_default_payload()),
             get_default_data()
-            ],
+        ],
         'private_type_preferred_store': [
             admin_a,
             'private',
             keys.get_private_key_pem(),
             get_private_key_req()
-            ],
+        ],
         'public_type_preferred_store': [
             admin_a,
             'public',
             keys.get_public_key_pem(),
             get_public_key_req()
-            ],
+        ],
         'certificate_type_preferred_store': [
             admin_a,
             'certificate',
             keys.get_certificate_pem(),
             get_certificate_req()
-            ],
+        ],
         'passphrase_type_preferred_store': [
             admin_a,
             'passphrase',
             'mysecretpassphrase',
             get_passphrase_req()
-            ],
+        ],
         'symmetric_type_no_preferred_store': [
             admin_b,
             'symmetric',
             oslo_base64.decode_as_bytes(get_default_payload()),
             get_default_data()
-            ],
+        ],
         'private_type_no_preferred_store': [
             admin_b,
             'private',
             keys.get_private_key_pem(),
             get_private_key_req()
-            ],
+        ],
         'public_type_no_preferred_store': [
             admin_b,
             'public',
             keys.get_public_key_pem(),
             get_public_key_req()
-            ],
+        ],
         'certificate_type_no_preferred_store': [
             admin_b,
             'certificate',
             keys.get_certificate_pem(),
             get_certificate_req()
-            ],
+        ],
         'passphrase_type_no_preferred_store': [
             admin_b,
             'passphrase',
             b'mysecretpassphrase',
             get_passphrase_req()
-            ],
+        ],
     })
     def test_secret_create_for(self, user_name, secret_type, expected, spec):
         """Create secrets with various secret types with multiple backends."""
